Back to Contents Page
Windows Driver Software: Broadcom NetXtreme BCM57XX User Guide
Installing the Driver Software
Updating the Driver Software
Removing the Device Drivers
Viewing or Changing the Properties of the Controller
Setting Power Management Options
Installing the Driver Software
NOTE: If your adapter was installed at the factory, the driver software has been installed for you.
When Windows first starts after a hardware device (such as a Broadcom NetXtreme Gigabit Ethernet adapter) has been installed, or after the existing device driver has been removed, the operating system automatically detects the hardware and prompts you to install the driver software for that device.
Both a graphical interactive installation mode (see Using the Installer) and a command-line silent mode for unattended installation (see Using Silent Installation) are available.
NOTES:
- Before installing the driver software, verify that the Windows operating system has been upgraded to the latest version with the latest service pack applied.
- A network device driver must be installed before the Broadcom NetXtreme Gigabit Ethernet adapter can be used with your Windows operating system. Drivers are located on the installation CD.
Using the Installer
- To install the Broadcom NetXtreme driversWhen Found New Hardware Wizard opens, click Cancel.
- Insert the installation CD into the CD-ROM or DVD drive.
- On the installation CD, open the folder for your operating system, open the DrvInst folder, and then double-click Setup.exe file to open the InstallShield Wizard.
- Click Next to continue.
- After you review the license agreement, click I accept the terms in the license agreement, and then click Next to continue.
- Select how you want to install the NetXtreme drivers and then click Next.
- Click Install.
- Click Finish to close the wizard.
- The installer will determine if a system restart is necessary. Follow the on-screen instructions.
Using Silent Installation
NOTES:
- All commands are case sensitive.
- User must "Run as Administrator" for Vista when using "msiexec" for "silent" install/uninstall(s).
- For more detailed instructions and information about unattended installs, refer to the Silent.txt file in the DrvInst folder.
To perform a silent install from within the installer source folder
Type the following:
setup /s /v/qn
-or-
msiexec /i "BDrvInst.msi" /qn
To perform a silent upgrade from within the installer source folder
Type the following:
setup /s /v/qn
To perform a silent uninstall from within the installer source folder
Type the following:
msiexec /x "BDrvInst.msi" /qn
To perform a silent uninstall from any folder
Type the following:
msiexec /x "{B7F54262-AB66-44B3-88BF-9FC69941B643}" /qn
To perform a silent reinstall of the same installer
Type the following:
setup /s /v"/qn REINSTALL=ALL"
To perform a GUI reinstall of the same installer
Type the following:
setup /V"REINSTALL=ALL"
Updating the Driver Software
To update the driver software
- Start Windows and log on. You must have administrative privileges to update the driver software.
- In Control Panel, click System to view System Properties.
- Click the Hardware tab, and then click Device Manager.
- Right-click the name of the Broadcom NetXtreme BCM57XX Gigabit Ethernet Controller and click Update Driver.
- Follow the on-screen instructions provided by the Hardware Update Wizard.
- Click Include this location in the search, browse to the folder on the installation CD where the drivers are located, and then click Next.
- Click Finish to close the wizard.
Removing the Device Drivers
- Open Add or Remove Programs in Control Panel.
- Click Broadcom NetXtreme Ethernet Controller, and then click Remove.
- Click Yes to remove the drivers and management applications.
- Restart your system.
NOTE: You can also remove the device drivers by running the InstallShield installer again and clicking Remove.
Viewing or Changing the Properties of the Controller
To view or change the properties of the Broadcom NetXtreme 57XX Gigabit Ethernet Controller
- Right-click the Control Suite icon in the taskbar notification area, and then click Launch BACS.
- Click the Advanced tab.
- See Setting Adapter Propertiesfor a detailed description of the available properties as well as for instructions for viewing and changing the value of a particular property.
NOTE: You can also open Broadcom Advanced Control Suite in Control Panel.
Setting Power Management Options
You can set Power Management options to allow the operating system to turn off the adapter to save power or to allow the adapter to wake up the system. If the device is busy doing something (servicing a call, for example) however, the operating system will not shut down the device. The operating system attempts to shut down every possible device only when the system attempts to go into hibernation. To have the adapter stay on at all times, do not select the Allow the computer to turn off the device to save power check box.
NOTES:
- The Power Management tab is available only for systems that support power management.
- To enable Wake on LAN (WOL) when the system is on standby, select the Allow the device to bring the computer out of standby check box.
- If you select Only allow management stations to bring the computer out of standby, the system can be brought out of standby only by Magic Packet, regardless of the settings in Wake Up Capabilities.
CAUTION! Do not select the Allow the computer to turn off the device to save power check box for any adapter that is a member of a team.
Updating Firmware
Broadcom provides a utility for upgrading bootcode and other firmware components. The utility is implemented as a console application that can be run from a Windows command prompt.
Installing the Firmware Upgrade Utility
To install the utility on a Windows system with Broadcom adapter software installed:
- Locate the BMAPI binary (dll) file in your software distribution.
- Copy to the same location on the system as winfwupg.exe.
Invoking the Utility
Use the winfwupg command to invoke the upgrade utility and access all of its commands:
Syntax
winfwupg [-all | [service_name | MAC]] [Commands]
Parameters
|
Parameter
|
Description
|
[-all [service_name | MAC]
|
The -all command applies to the upgrade and restorenvram commands only.
The service_name/MAC is optional for the help, version, and dev commands, but it is required for all other commands.
Note the following:
- When
-all is specified, neither service_name nor MAC can be specified. Both the upgrade and the restorenvram commands use the device information in the image to apply to all NICs that match the same device ID.
- On Windows,
service_name is the service GUID in the form: {xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx}
For example, {4D36E972-E325-11CE-BFC1-08002bE10318} refers to the series of numbers that Windows uses to identify the adapter. This can be obtained based on the value in the registry NetCfgInstanceId string located at:
HKEY_LOCAL_MACHINE\System\CurrentControlSet\Control\Class\{4D36E972-E325-11CE-BFC1-08002BE10318}\####, where '####' reflects the enumeration number of the Broadcom adapter.
- MAC is the MAC address name of the NIC in the system. For example, if
00:10:18:00:11:99 is a valid MAC address as shown in the ipconfig utility, then use 001018001199 as an input parameter to select the NIC.
|
[Commands]
|
The following is the list of available commands. These are described in detail following this table.
help: Shows a list of available commands.
q: Exits the program.
cfg: Configure NVRAM.
dev: Select an adapter or List available adapters.
dir: Display file directory in NVRAM.
crc: Check/update NVRAM checksum.
dumpnvram: Save entire NVRAM content to a file.
prg: Program NVRAM with specified firmware image This command is designated to facilitate the manufacture operation.
restorenvram: Restore entire NVRAM contents from a file.
version: Display version of this program.
upgrade: Upgrades the firmware or bootcode.
-w: Enable/disable WOL (deprecatedInstaed use cfg -wol <value>.
otpchk: Check OTP content against the specified file.
|
Command Descriptions
The commands that can be used with the winfupg utility are described in the tables that follow.
|
upgrade
|
|
|
Syntax
|
upgrade [-noreset] [-F] {-bc|-mba|-asf|-ump|-mgmt|-mgmt_ia|-ib|-ib_ipv6|-ib_ipv4n6|-vpd|-usr|-ccm} [-c] [-p] {<filename>} [<savefile>]
|
|
Description
|
This command upgrades the firmware or bootcode for the NetXtreme controller. The <filename> specifies the name of the file that contains the appropriate image. The <savefile> specifies the name of the file to which the current NVRAM contents will be saved. If <savefile> is not specified, the current NVRAM contents will not be saved.
Both <filename> and <savefile> are mandatory parameters. If the upgrade version is same or older than the version in NVRAM, upgrade will be aborted. The -noreset option is to skip the driver restart of the selected NIC after the firmware upgrade is completed. This option is valid only in Command Line Mode.
|
|
Parameters
|
-F: Forces the upgrade without checking version.
-mba: MBA (PXE) firmware
-ump: UMP firmware
-asf: ASF firmware
-mgmt: DASH firmware
-mgmt_ia: Inactive Management firmware
-ib: iSCSI boot firmware to support IPv4
-ib_ipv6: iSCSI boot firmware to support IPv6
-ib_ipv4n6: iSCSI boot firmware to support IPv4 and IPv6
-vpd: Extended VPD
-usr: User block
-ccm: CCM firmware
[-c], [-p]: These options are valid only when "-ib" option is specified.
-c: Upgrades the iSCSI configuration along with iSCSI boot code. The -ib, -ib_ipv6, and -ib_ipv4n6 commands add/upgrade the iSCSI configuration automatically. Therefore, this option is no longer needed.
-p: Upgrades the iSCSI configuration program along with iSCSI boot code.
|
|
reset
|
|
|
Syntax
|
reset
|
|
Description
|
Resets the selected NIC. This command is valid only in Command Line Mode.
|
|
-w
|
|
|
Syntax
|
-w {<value>}
|
|
Description
|
Enables or disables WOL settings.
|
|
Parameters
|
{<value>}:
- Set to '1' to enable WOL.
- Set to '0' to disable WOL.
|
|
restorenvram
|
|
|
Syntax
|
restorenvram {<filename>} [idmatch] [config [mac]]
|
|
Description
|
This command reads complete NVRAM image from a file and writes the image to NVRAM.
Before writing the NVRAM image to adapter, verifications against source NVRAM image will be performed. If any verification failed, the image will not be written to adapter.
|
|
Parameters
|
<filename>: The file name of NVRAM image that was dumped from the NIC. <filename> is a mandatory parameter.
idmatch: Requests the Firmware Upgrade Tool to restore the NVRAM image only after the 4 IDs (vendor_id, device_id, subsystem_vendor_id, subsystem_device_id) in the image file match those in the device. This is on top of all previous criteria that have to be met.
config: The configuration area will copy from source image except MAC address. Configuration area includes MAC address and various options.
mac: Applies only when 'config' is specified. When 'mac' is specified, all configuration are copied, including MAC address.
|
|
dumpnvram
|
|
|
Syntax
|
dumpnvram{<filename>}
|
|
Description
|
Dumps the NVRAM contents to the specified file.
|
|
Parameters
|
<filename> is a mandatory parameter.
|
|
crc
|
|
|
Syntax
|
crc
|
|
Description
|
Checks the integrity of the NVRAM CRC
|
|
dir
|
|
|
Syntax
|
dir [-delete <type>]
|
|
Description
|
Displays a listing of the firmware programmed in NVRAM.
|
|
Parameters
|
-delete: Delete the specified <type> in the directory and its firmware from NVRAM. The FwUpg tool will return successfully if the firmware is not existing.
<type>: The type of firmware to be deleted. The keyword strings used for <type> are as follows:
- MBA: MBA/PXE
- ASFINIT: ASF Init
- ASFCPUA: ASF CPUA
- ASFCPUB: ASF CPUB
- ASFCFG: ASF CFG
- ISCSICFG: iSCSI CFG for port 0
- ISCSIPRG: iSCSI CFG Program
- ISCSIBOOT: iSCSI Boot
- ISCSICFG1: iSCSI CFG for port 1
- APECFG: APE CFG
- APECODE: APE firmware
- APECODENA: Inactive APE firmware
- APEUPDATE: APE update firmware
- APEDATA: APE data
- APEWEBDATA: APE Web data
- APEWORKAROUND: APE Workaround
- EXTVPD: Extended VPD
- APEAUDITLOG: APE Audit Log
- APEEVENTLOG: APE Event Log
- ISCSICFG2: iSCSI CFG for port 2
- ISCSICFG3: iSCSI CFG for port 3
- CCM: CCM firmware
|
|
dev
|
|
|
Syntax
|
dev [<number>]
|
|
Description
|
Selects the target device.
|
|
Parameters
|
<number>: The number of the adapter to be selected as target device.
|
|
prg
|
|
|
Syntax
|
prg {-bc|-ib|-mba|-ccm} {<new_image>} [-c] [-p] [-mac]
|
|
Description
|
Programs NVRAM with the specified firmware image.
|
|
Parameters
|
Note: Not all adapters support each of the following parameters.
-bc: Bootcode. The image file for the prg -bc command must contain ONLY valid bootcode without other firmware directories.
-ib: iSCSI boot firmware. The image file for the prg -ib command must contain ONLY valid iSCSI boot without other firmware directories.
-mba: MBA firmware.
-ccm: CCM firmware.
<new_image>: A mandatory parameter to specify the input binary file.
-c: Force to program iSCSI configuration. This option is valid only if the -ib option is used.
-p: Force to program iSCSI configuration utility program. This option is valid only if the -ib option is used.
-mac: Force to program MAC address. This option is valid only if the-bc option is used.
|
|
otpchk
|
|
|
Syntax
|
otpchk [-mac] {<filename>}
|
|
Description
|
Compares the OTP content to the content of the specified file. By default, it compares all the patches in the OTP and the patches in the specified file.
|
|
Parameters
|
- -mac: The compare function will include the MAC address and the configuration.
- <filename>: The file to compare to the OTP content.
|
|
cfg
|
|
|
Syntax
|
cfg [-noreset] {-mac <MAC address to be programmed for current selected device> | -mba <value> | -asf <value> | -ump <value> | -setman <t|p|m> |
-mgmt <value> | -wol <value> | -aspm <value> | -tph <value> |-vpdv0 <version string> | -show}
|
|
Description
|
Programs the specified configuration into NVRAM.
|
|
Parameters
|
-noreset: Skips the driver restart of the selected NIC after the firmware upgrade is completed. This option is only valid in Command Line Mode. It is not supported on all NICs. On NICs where it is not supported, APE needs to be suspended before configuring the parameter in NVRAM, since the DASH/SMASH firmware might access the NVRAM during the configuring process.
-mac: <MAC address for current selected device> is a 12-digit HEX MAC address, e.g. 0010181a2b3c.
-mba: Set <value> to '1' to enable MBA firmware. Set <value> to '0' to disable mba firmware.
-asf: Set <value> to '1' to enable ASF firmware. Set <value> to '0' to disable asf firmware.
-ump: Set <value> to '1' to enable UMP firmware. Set <value> to '0' to disable ump firmware.
-setman: Set APE active management firmware.
t: Toggle APE active management firmware.
p: Activate Inactive APE management firmware if it is PASSTHRU.
m: Activate Inactive APE management firmware if is TruManage.
-mgmt: Set <value> to '1' to enable management firmware. Set <value> to '0' to disable management firmware.
-wol: Set <value> to '1' to enable wol feature. Set <value> to '0' to disable WOL feature.
-aspm: Set <value> to '1' to enable L1 ASPM debounce feature. Set <value> to '0' to disable L1 ASPM debounce feature.
-tph: Set <value> to '2' to advertise TPH with ST mode. Set <value> to '1' to advertise TPH without ST mode. Set <value> to '0' to disable TPH feature.
-vpdv0: Set <value> to VPD V0 tag. <version string> can be put inside quotes to include the space char.
-show: Shows the settings of current configuration.
|
Examples
Command Line Mode Examples
WinFWUpg
Enters interactive mode.
WinFwUpg upgrade -bc C:/tmp/new_bootcode c:\\oldBoot
Upgrades bootcode for the ONLY qualified adapter found. The adapter parameter can be omitted if ONLY ONE qualified adapter is found.
WinFwUpg 001018001199 upgrade -mba b57mmbae.nic c:\\backup\\oldPXE.bin'
Upgrades PXE for the adapter with MAC 00:10:18:00:11:99.
WinFWUpg {8580CDDC-961B-4829-A80C-478D22DB7B3E} upgrade -F -asf asfv55 old_image
Upgrades ASF for the adapter with the specified GUID.
WinFWUpg -all upgrade -F -ump c:/tmp/ump114 backupUMP
Forces a downgrade for all the BRCM 5714/15/80 adapters with existing UMP support. When multiple applicable adapters are present, the MAC address of the adapter is appended to the backup NVRAM image parameter filename.
WinFWupg -all restorenvram "c:/Documents and Settings/backup.bin" config
Reads a complete NVRAM image from file 'backup.bin' and write the image to NVRAM along with its configurations. If 'config' parameter is left out, only the image is written. This will only restore NVRAM images to those with matching FW, with the exception to variations in version numbers.
WinFwUpg prg -bc C:/tmp/fresh_bootcode
Programs bootcode for the ONLY qualified adapter found. The adapter parameter can be omitted if ONLY ONE qualified adapter is found.
WinFwUpg 0010181a1b1c cfg -mac 0010189d9e9f
Configures the selected adapter whose current MAC address is 00:10:18:1a:1b:1c to be the new MAC address 00:10:18:9d:9e:9f.
WinFwUpg 0010189a9b9c cfg -asf 1
Enables asf firmware if the asf firmware is present in the selected adapter whose current MAC address is 00:10:18:9a:9b:9c.
Interactive Mode Examples
help
Displays a list and descriptions of available commands.
q
Exits the utility.
dev
Displays a list of upgradeable devices.
dev 0
Selects device 0.
dir
Displays a listing of the firmware programmed in NVRAM.
crc
Checks the integrity of the NVRAM CRC.
dumpnvram c:\backup.bin config mac
Includes all configurations including the MAC address and saves the dump file to the c drive.
restorenvram "c:\Document and Settings\backup.bin" config mac
Includes all configurations including the MAC address. In order to verify the MAC address was configured, exiting the program will be necessary followed by either disabling and enabling the adapter or rebooting the system.
upgrade -bc ee5755c3.19 backup5755.bin
Upgrades the boot code for a BRCM 5755 adapter.
version
Displays the version of Firmware Upgrade utility.
-w 1
Enables the WOL setting on the current adapter.
prg -bc C:/tmp/new_bootcode
Programs a blank NVRAM or overwrite NVRAM with the specified bootcode.
cfg -mac 0010181a2b3c
Configures MAC address for the selected qualified adapter.
cfg -ump 0
Disables ump firmware if the ump firmware is present in the selected adapter.
dir -delete MBA
Deletes the MBA firmware from NVRAM.
dir -delete APEUPDATE
Deletes APE UPDATE firmware from NVRAM.
Considerations for Windows Vista
Administrative privileges are still required in order to run the utility under Windows Vista. However, when the user is other than the local Administrator, the location for the backup file should not be in a secure location as defined by the User Account Control feature ( An example of a secured location includes, but is not limited to, the root of the system drive). Otherwise, the User Account feature must be disabled in order for the utility to function correctly and save the backup file to the desired secure location.
Back to Contents Page